scoring module
==============

.. automodule:: whoosh.scoring

Scoring algorithm classes
-------------------------

.. autoclass:: Weighting
    :members:

.. autoclass:: BM25F

.. autoclass:: Cosine

.. autoclass:: DFree

.. autoclass:: DLH13

.. autoclass:: Hiemstra_LM

.. autoclass:: InL2

.. autoclass:: TF_IDF

.. autoclass:: Frequency

Sorting classes
---------------

.. autoclass:: Sorter

.. autoclass:: NullSorter

.. autoclass:: FieldSorter

.. autoclass:: MultiFieldSorter


